==> cdk-codepipeline-badge-notification-0.2.61.tar.gz: package/lib/main.d.ts <==
import * as cdk from '@aws-cdk/core';
/**
 * @experimental
 */
export interface Notification {
    /**
     * (experimental) Prefix title for slack message.
     *
     * @experimental
     */
    readonly stageName?: string;
    /**
     * (experimental) Slack webhook url from ssm parameter.
     *
     * @experimental
     */
    readonly ssmSlackWebHookUrl?: string;
    /**
     * (experimental) google chat webhook url from ssm parameter.
     *
     * @experimental
     */
    readonly ssmGoogleChatWebHookUrl?: string;
    /**
     * (experimental) telegram webhook url from from ssm parameter the URL is not include text query string.
     *
     * @experimental
     */
    readonly ssmTelegramWebHookUrl?: string;
}
/**
 * @experimental
 */
export interface GitHubTokenFromSecretsManager {
    /**
     * (experimental) Arn with other type of secrets.
     *
     * @experimental
     */
    readonly secretsManagerArn?: string;
    /**
     * (experimental) SecretKey.
     *
     * @experimental
     */
    readonly secretKey?: string;
}
/**
 * @experimental
 */
export interface CodePipelineBadgeNotificationProps {
    /**
     * (experimental) AWS CodePipeline arn.
     *
     * @experimental
     */
    readonly pipelineArn: string;
    /**
     * (experimental) AWS Secret Manager id or arn.
     *
     * @experimental
     */
    readonly gitHubTokenFromSecretsManager?: GitHubTokenFromSecretsManager;
    /**
     * (experimental) Notification.
     *
     * @experimental
     */
    readonly notification?: Notification;
}
/**
 * @experimental
 */
export declare class CodePipelineBadgeNotification extends cdk.Construct {
    /**
     * @experimental
     */
    badgeUrl: string;
    /**
     * @experimental
     */
    codePipelineLink: string;
    /**
     * @experimental
     */
    constructor(scope: cdk.Construct, id: string, props: CodePipelineBadgeNotificationProps);
    private createCodePipelineEventLambdaFunction;
    private tagResource;
}

==> cdk-codepipeline-badge-notification-2.0.32.tar.gz: package/lib/main.d.ts <==
import { Construct } from 'constructs';
/**
 * @experimental
 */
export interface Notification {
    /**
     * (experimental) Prefix title for slack message.
     *
     * @experimental
     */
    readonly stageName?: string;
    /**
     * (experimental) Slack webhook url from ssm parameter.
     *
     * @experimental
     */
    readonly ssmSlackWebHookUrl?: string;
    /**
     * (experimental) google chat webhook url from ssm parameter.
     *
     * @experimental
     */
    readonly ssmGoogleChatWebHookUrl?: string;
    /**
     * (experimental) telegram webhook url from from ssm parameter the URL is not include text query string.
     *
     * @experimental
     */
    readonly ssmTelegramWebHookUrl?: string;
}
/**
 * @experimental
 */
export interface GitHubTokenFromSecretsManager {
    /**
     * (experimental) Arn with other type of secrets.
     *
     * @experimental
     */
    readonly secretsManagerArn?: string;
    /**
     * (experimental) SecretKey.
     *
     * @experimental
     */
    readonly secretKey?: string;
}
/**
 * @experimental
 */
export interface CodePipelineBadgeNotificationProps {
    /**
     * (experimental) AWS CodePipeline arn.
     *
     * @experimental
     */
    readonly pipelineArn: string;
    /**
     * (experimental) AWS Secret Manager id or arn.
     *
     * @experimental
     */
    readonly gitHubTokenFromSecretsManager?: GitHubTokenFromSecretsManager;
    /**
     * (experimental) Notification.
     *
     * @experimental
     */
    readonly notification?: Notification;
}
/**
 * @experimental
 */
export declare class CodePipelineBadgeNotification extends Construct {
    /**
     * @experimental
     */
    badgeUrl: string;
    /**
     * @experimental
     */
    codePipelineLink: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: CodePipelineBadgeNotificationProps);
    private createCodePipelineEventLambdaFunction;
    private tagResource;
}
